@@ -140,12 +140,13 @@ int dbd_db_login(SV* dbh, imp_dbh_t* imp_dbh, char* dbname, char* user,
     /*
      *  Try to connect
      */
-    if (!dbd_db_connect(&imp_dbh->svsock, host, user, password)) {
+    if (!dbd_db_connect(&imp_dbh->svsock, host, user, password, NULL)) {
 	DO_ERROR(dbh, JW_ERR_CONNECT, imp_dbh->svsock);
 	if (copy) free(copy);
 	return FALSE;
     }
 
+#if !defined(DBD_MYSQL)  ||  !defined(MYSQL_VERSION_ID)  ||  (MYSQL_VERSION_ID < 32200)
     /*
      *  Connected, now try to login
      */
@@ -155,6 +156,7 @@ int dbd_db_login(SV* dbh, imp_dbh_t* imp_dbh, char* dbname, char* user,
 	MyClose(imp_dbh->svsock);
 	return FALSE;
     }
+#endif
 
     if (copy) free(copy);
 
